betty.serde package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.serde package

## Subpackages

- betty.serde.format package
  - Submodules
    - betty.serde.format.formats module
      - `Json`
        - `Json.dump()`
        - `Json.extensions()`
        - `Json.load()`
      - `Yaml`
        - `Yaml.dump()`
        - `Yaml.extensions()`
        - `Yaml.load()`
  - Module contents
    - `FORMAT_REPOSITORY`
    - `Format`
      - `Format.dump()`
      - `Format.extensions()`
      - `Format.load()`
    - `FormatError`
    - `FormatRepository`
      - `FormatRepository.__init__()`
      - `FormatRepository.extensions()`
      - `FormatRepository.get()`
    - `FormatStr`
      - `FormatStr.__init__()`
      - `FormatStr.localize()`
    - `format_for()`

## Submodules

- betty.serde.dump module
  - `Dump`
  - `DumpMapping`
  - `DumpSequence`
  - `Dumpable`
    - `Dumpable.dump()`
- betty.serde.load module
  - `Loadable`
    - `Loadable.load()`

## Module contents

Provide Betty’s serialization and deserialization API.